@@ -22,12 +22,11 @@
 #ifndef __GEDIT_METADATA_MANAGER_H__
 #define __GEDIT_METADATA_MANAGER_H__
 
-#include <glib.h>
 #include <gio/gio.h>
 
 G_BEGIN_DECLS
 
-void		 gedit_metadata_manager_init		(void);
+void		 gedit_metadata_manager_init		(const gchar *metadata_filename);
 
 void		 gedit_metadata_manager_shutdown 	(void);
 
